==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/UserformCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Userform;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.UserformRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class UserformCollectionRequest extends CollectionPageEntityRequest<Userform, UserformRequest>{

    protected ContextPath contextPath;

    public UserformCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Userform.class, cp -> new UserformRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public AsyncoperationCollectionRequest userForm_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("UserForm_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest userForm_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("UserForm_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest userForm_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("UserForm_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest userForm_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("UserForm_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/UserformCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Userform;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.UserformRequest;

public class UserformCollectionRequest extends CollectionPageEntityRequest<Userform, UserformRequest>{

    protected ContextPath contextPath;

    public UserformCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Userform.class, cp -> new UserformRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public AsyncoperationCollectionRequest userForm_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("UserForm_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest userForm_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("UserForm_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest userForm_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("UserForm_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest userForm_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("UserForm_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

}
